<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Programma_Naam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>Gebruik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>Dock Preview</source>
        <translation>Dock Voorbeeld</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Add New Application</source>
        <translation>Nieuwe Applicatie Toevoegen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <source>Command</source>
        <translation>Commando</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Add application</source>
        <translation>Applicatie toevoegen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <source>Delete this application</source>
        <translation>Verwijder deze applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Background</source>
        <translation>Achtergrond</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.cpp" line="739"/>
        <location filename="../mainwindow.cpp" line="853"/>
        <location filename="../mainwindow.cpp" line="866"/>
        <location filename="../mainwindow.cpp" line="890"/>
        <source>Select icon...</source>
        <translation>Selecteer icoon...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <location filename="../mainwindow.cpp" line="95"/>
        <location filename="../mainwindow.cpp" line="686"/>
        <location filename="../mainwindow.cpp" line="743"/>
        <location filename="../mainwindow.cpp" line="856"/>
        <source>Select...</source>
        <translation>Selecteer...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>36x36</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <source>40x40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Move right</source>
        <translation>Beweeg naar rechts</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Move left</source>
        <translation>Beweeg naar links</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="461"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="542"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="583"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Alt+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="118"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation>1. Voeg een voor een toepassingen toe aan de dock
2. Selecteer een .desktop-bestand of voer een opdracht in voor de toepassing die u wilt gebruiken
3. Selecteer icoon attributen voor grootte, achtergrond (zwart is standaard) en rand
4. Druk op &quot;Applicatie toevoegen&quot; om verder te gaan of op &quot;Opslaan&quot; om te eindigen</translation>
    </message>
    <message>
        <source>black</source>
        <translation type="vanished">zwart</translation>
    </message>
    <message>
        <source>white</source>
        <translation type="vanished">wit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation>Met dit gereedschap kunt u een nieuwe dock creëren met één of meerdere toepassingen. U kunt ook een eerder aangemaakt dock bewerken of verwijderen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="164"/>
        <source>Operation mode</source>
        <translation>Werk modus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <source>&amp;Move</source>
        <translation>&amp;Verplaats</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>&amp;Delete</source>
        <translation>&amp;Delete</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>&amp;Edit</source>
        <translation>&amp;Aanpassen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>C&amp;reate</source>
        <translation>&amp;Creëer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Dock name</source>
        <translation>Dock naam</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>Voer de naam in die in het Menu te zien is:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Select dock to delete</source>
        <translation>Selecteer dock die u wilt verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Confirmation</source>
        <translation>Bevestiging</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Weet U zeker dat U %1 wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Select dock to move</source>
        <translation>Selecteer dock om te verplaatsen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <location filename="../mainwindow.cpp" line="362"/>
        <location filename="../mainwindow.cpp" line="543"/>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation>Dock Bestanden (*.mxdk);;Alle Bestanden (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <location filename="../mainwindow.cpp" line="396"/>
        <location filename="../mainwindow.cpp" line="811"/>
        <source>Could not open file</source>
        <translation>Kon bestand niet openen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>Overwrite?</source>
        <translation>Overschrijven?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation>Wilt u het dock bestand overschrijven?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>Save file</source>
        <translation>Bestand opslaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="608"/>
        <source>Dock saved</source>
        <translation>Dock opgeslagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation>Het dock is opgeslagen.

Om het nieuw aangemaakte dock te bewerken selecteert u &apos;Bewerk een bestaand dock&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>MX Dockmaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Description goes here</source>
        <translation>Beschrijving komt hier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="642"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="779"/>
        <source>Select .desktop file</source>
        <translation>Kies .desktop bestand</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="780"/>
        <source>Desktop Files (*.desktop)</source>
        <translation>Desktop Bestanden (*.desktop)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="800"/>
        <source>Select a dock file</source>
        <translation>Selecteer een dock bestand</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="804"/>
        <source>No file selected</source>
        <translation>Geen bestand geselecteerd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="805"/>
        <source>You haven&apos;t selected any dock file to edit.
Creating a new dock instead.</source>
        <translation>U hebt geen enkel dockbestand geselecteerd om te bewerken.
In plaats daarvan nieuw dock creëren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="812"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation>Kon geselecteerd bestand niet openen.
In plaats daarvan nieuw dock creëren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="820"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation>1. Pas applicaties een voor een aan met de Terug en Vooruit knoppen
2. Voeg toe of verwijder applicaties zo u wilt
3. Wanneer klaar druk op Opslaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="872"/>
        <source>Select icon</source>
        <translation>Selecteer icoon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="873"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation>Iconen (*.png *.jpg *.bmp *.xpm *.svg)</translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="../picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation>Dock Locatie</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>BovenMidden</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>OnderLinks</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>OnderMidden</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>BovenLinks</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>BovenRechts</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation>LinksMidden</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation>RechtsMidden</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>OnderRechts</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>RechtsBoven</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>LinksBoven</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>LinksOnder</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>RechtsOnder</translation>
    </message>
    <message>
        <location filename="../picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation>Selecteer dock locatie</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>License</source>
        <translation type="vanished">Licentie</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Changelog</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Ongedaan maken</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Close</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Fout</translation>
    </message>
    <message>
        <source>You must run this program as normal user.</source>
        <translation type="vanished">U moet dit programma als normale gebruiker uitvoeren.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>License</source>
        <translation type="unfinished">Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <location filename="../about.cpp" line="49"/>
        <source>Changelog</source>
        <translation type="unfinished">Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>Cancel</source>
        <translation type="unfinished">Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="62"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished">Fout</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished">U moet dit programma als normale gebruiker uitvoeren.</translation>
    </message>
</context>
</TS>
